ams.core.service.RampSub
========================

.. currentmodule:: ams.core.service

.. autoclass:: RampSub

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~RampSub.assign_memory
       
       
          ~RampSub.evaluate
       
       
          ~RampSub.get_names
       
       
          ~RampSub.parse
       
       
          ~RampSub.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~RampSub.class_name
      ~RampSub.n
      ~RampSub.shape
      ~RampSub.size
      ~RampSub.v
      ~RampSub.v0
      ~RampSub.v1
   
   